icenet.data.loaders package
===========================

Submodules
----------

icenet.data.loaders.base module
-------------------------------

.. automodule:: icenet.data.loaders.base
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.loaders.dask module
-------------------------------

.. automodule:: icenet.data.loaders.dask
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.loaders.stdlib module
---------------------------------

.. automodule:: icenet.data.loaders.stdlib
    :members:
    :undoc-members:
    :show-inheritance:

icenet.data.loaders.utils module
--------------------------------

.. automodule:: icenet.data.loaders.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: icenet.data.loaders
    :members:
    :undoc-members:
    :show-inheritance:
